' VBScript to Add a Continuous Entity
'   lines starting with an apostrophe are comments

' create Visual CADD and point objects
set vcadd = CreateObject("VisualCADD.Application.9")
set pt0 = CreateObject("VisualCADD.Point2D.9")

'  Optional - Set properties for the new entity:
'       While all the properties can be modified after the entity 
'       has been added to the database, it is convenient to set 
'       the properties prior to the operation.
'       The properties for entities typically include layer, 
'       color, line type, and line width.  These can be set with 
'       the following API calls.
'       If you do not set a specific property, Visual CADD will 
'       use the current properties when creating the entity.
'       Compound entities such as dimensions, text, fills, and
'       hatches require specific settings for the respective 
'       entity type.
'       The following code sets the layer index to 5, 
'       the color property to blue (index 9), 
'       the line type property to SOLID (index 0),
'       and the line width property index to 1 (pixel).

vcadd.SetLayerIndex(5)
vcadd.SetColorIndex(9)
vcadd.SetLineTypeIndex(0)
vcadd.SetLineWidthIndex(1)

'  Add a reference to the entity to the database:
'       Continuous entities allow for a multiple number of points 
'       defining the geometry.  These points must be set after the 
'       entity has been added in the database.  Like the single 
'       entities, the defining points can be defined through code or 
'       through user interaction within the interface.  The following
'       code adds a Continuous Bezier entity initially with no points.
'       The -1 means to place the entity in the drawing, other 
'       options can place it in a symbol definition.

vcadd.AddContinuousBezierEntity(-1)

'       In order to add placement points to the geometry, the new 
'       entity must be set current.  This ensures the point 
'       operations are applied to the correct entity.  Each entity 
'       in the drawing database is referenced based on a handle or 
'       index allowing applications to quickly access entities with 
'       VCSetCurrentEntity.  The following code gets the handle 
'       (index) of the newly placed entity and sets it as the current 
'       entity.

hEnt = vcadd.LastEntity()
vcadd.SetCurrentEntity(hEnt)

'   Set the points for the continuous entity:
'       Since a continuous entity allows for a variable number 
'       of points, the application can set the points one at a 
'       time as often as needed.  This is done by using the 
'       VCSetCurrentEntityPoint function to set the points.
'       The following code sample adds 10 calculated points 
'       to the Continuous Bezier entity.

For index = 0 To 9
    pt0.X = index
    pt0.Y = 10.0 / (1.0 + index)

    vcadd.SetCurrentEntityPoint index, pt0
Next

'  Optional - Draw the new entity to the screen:
'       New entities are not automatically displayed on the 
'       screen after being added to the database.  The entity 
'       will be drawn during the next redraw or paint event,
'       such as a VCZoomAll() or a UI command Regen/RD.  In order
'       to draw the entity immediately, use VCDrawCurrentEntity:

vcadd.DrawCurrentEntity

' release Visual CADD and point objects
set vcadd = Nothing
set pt0 = Nothing
