' VBScript to Add a Reference Frame Entity
'   lines starting with an apostrophe are comments

' create Visual CADD and point objects
set vcadd = CreateObject("VisualCADD.Application.9")
set pt0 = CreateObject("VisualCADD.Point2D.9")

'   Set the filename to add as the reference frame:
'       The reference frame contains a drawing that is to be 
'       referenced inside the active drawing. The path and 
'       filename for the drawing are required to define the 
'       entity.  The following code references a drawing 
'       named SAMPLE.VCD from the active directory:

vcadd.SetRefFrameName("SAMPLE.VCD")

'   Optional: Set the desired frame properties:
'       A reference frame has specific properties that apply 
'       only to this entity type. These include boundary color, 
'       line width, and display, offset, rotation, and scale. 
'       Each of these properties can be altered after the entity 
'       has been placed however it is convenient to set these 
'       prior to adding the entity.  The following code sets 
'       the boundary display off and the rotation to 45 degrees.
'       NOTE: All angles must be entered in radians. PI/4 
'       represents 45 degrees in radians.

vcadd.SetRefFrameDrawBoundary(0)
vcadd.SetRefFrameRot(3.14159 / 4.0)

'   Bind or link the data as desired:
'       The referenced drawing can either be bound or linked to 
'       the reference frame entity. Bound data causes the 
'       reference frame to store the vector information directly 
'       in the active drawing while linked data stores only a 
'       reference to the external file.  Linked drawings will 
'       reflect changes made after the file has been added.  
'       Bound data will cause the drawing size to enlarge since 
'       all the reference file information is not stored in the 
'       new drawing.  The following code specifies for the 
'       reference frame to contain linked, not bound, data:

vcadd.SetRefFrameIsDataBound(0)

'   Optional: Set the reference frame size.
'       A reference frame defaults to the size of the file that 
'       is being referenced.  In situations where several 
'       reference frames are used to reference a drawing, it may 
'       be desirable to specify the frame size in order to have 
'       the referenced drawing fit to a certain position.  The 
'       following code sets the frame height and width to 12 
'       inches each.  NOTE: The X value of the point represents 
'       the width while the Y value represents the height.

pt0.X = 12.0
pt0.Y = 12.0

vcadd.SetRefFrameViewWidthHeight(pt0)

'   Add the reference frame:
'       The reference frame entity can now be added to the drawing 
'       database.  The following adds the reference frame entity 
'       to the drawing at 0, 0:

pt0.X = 0.0
pt0.Y = 0.0

vcadd.AddRefFrameEntity -1, pt0 

' release Visual CADD and point objects
set vcadd = Nothing
set pt0 = Nothing
