' VBScript to Add a Text Entity
'   lines starting with an apostrophe are comments

' create Visual CADD and point objects
set vcadd = CreateObject("VisualCADD.Application.9")
set pt0 = CreateObject("VisualCADD.Point2D.9")

'   Optional: Set the properties for the new entity:
'       Text settings have their own specific settings separate 
'       from the drawing properties of layer, color, line type, 
'       and line width settings.  If no settings are specified, 
'       Visual CADD will use the current settings.  The 
'       following code sets the text layer to 8, color to 
'       blue (index 9), left justified, height 3 inches, and 
'       text string to Hello World!:

vcadd.SetTextLayer(8)
vcadd.SetTextColor(9)
vcadd.SetTextJustify(Asc("L"))
vcadd.SetTextHeight(3.0)
vcadd.SetTextString("Hello World!")

'   Add the entity to the database:
'       Text entities only require an insertion point for the string.

pt0.X = 0.0
pt0.Y = 0.0

'       The following code adds the text entity to the drawing:

vcadd.AddTextEntity -1, pt0 

'   Optional - Make the new entity the current entity:
'       A new entity is always appended to the end of the 
'       database and given an entity handle (index) one greater 
'       than the previous last entity.  It may be necessary to 
'       make the new entity current for tracking its ID, changing
'       properties, redrawing to the screen, adding data to the 
'       entity, or other operations.  Each entity in the drawing
'       database is referenced by an entity handle (index) 
'       allowing applications to quickly access entities with 
'       VCSetCurrentEntity.
'       The following code sets the newly placed entity as the 
'       current entity.

hEnt = vcadd.LastEntity()
vcadd.SetCurrentEntity(hEnt)

'   Optional - Draw the new entity to the screen:
'       New entities are not automatically displayed on the 
'       screen after being added to the database.  The entity 
'       will be drawn during the next redraw or paint event,
'       such as a VCZoomAll() or a UI command Regen/RD.  In order
'       to draw the entity immediately, use VCDrawCurrentEntity:

vcadd.DrawCurrentEntity()

' release Visual CADD and point objects
set vcadd = Nothing
set pt0 = Nothing
