' VBScript to Apply Settings to an Entity
'   lines starting with an apostrophe are comments

' create Visual CADD object
set vcadd = CreateObject("VisualCADD.Application.9")

'   Move to the desired entity(ies) in the database:
'       This can be done with all the general parsing 
'       routines or directly with VCSetCurrentEntity.  
'       See Parsing the Database.  The following code parses
'       through a selection made by the user before he starts 
'       the tool:

'   Save the current settings:
'       It is generally desirable to save the user settings 
'       prior to changing the values. These settings can then 
'       be restored at the end of the tool.  The following 
'       code saves the current user drawing settings to a 
'       temporary buffer:

vcadd.SaveSettings()

'   start at the first selected entity
Dim iKind
iKind = vcadd.FirstSelected()

Do While (vcadd.GetErrorCode() = 0)

    '   your tool would do whatever processing is required
    '       for example, change entity properties

    '   match all the entity properties
    vcadd.MatchCurrentEntity()

    '   change only the desired properties:
    '       Note, when using VCApplySettingsToCurrentEntity
    '       you may also change any entity-specific setting, 
    '       such VCSetTextHeight, VCSetLeaderArrowType, etc.  
    '       If so, you should always check the entity type, 
    '       the iKind variable, to verify you have the 
    '       desired entity type.  For example, change color
    '       and line width:
    vcadd.SetColorIndex(10)
    vcadd.SetLineWidthIndex(1)

    '   Apply the settings to the current entity:
    '       After the new settings have been made, they need 
    '       to be applied to the current entity.  The 
    '       following code applies the new settings to the 
    '       current entity.  This method does not directly 
    '       support undo/redo.  However, when used in 
    '       conjunction with other techniques, the changes 
    '       you make can be undone.  Please refer to the 
    '       Managing Undo and Redo topic.

    vcadd.ApplySettingsToCurrentEntity()

    '   move to the next entity
    iKind = vcadd.NextSelected()
Loop

'   Restore the user default settings:
'       The user settings should be returned to their 
'       position prior to the operation.  VCRestoreSettings 
'       resets the settings based on the temporary buffer. 

vcadd.RestoreSettings()

'   de-select
vcadd.DeSelectAll()

' release Visual CADD object
set vcadd = Nothing
