' VBScript to Duplicate Entities with Transformation
'   lines starting with an apostrophe are comments

' create Visual CADD object
set vcadd = CreateObject("VisualCADD.Application.9")
set pt0 = CreateObject("VisualCADD.Point2D.9")

'  an entity handle, an index into the drawing database
Dim hEnt
Dim hCurrEnt

'   Optional - Save the current drawing settings:
'       When modifying entities, it is generally desirable 
'       to maintain the current settings in a temporary 
'       buffer and restore the information on completion.  
'       This allows the user to continue using his original 
'       settings without unexpected changes.  The following 
'       code stores the settings into a temporary buffer:

vcadd.SaveSettings()

'   Retrieve the ENTITYHANDLE for the entity to be 
'   duplicated:
'       In order to duplicate an entity, an application needs
'       to retrieve the handle for the entity.  This handle 
'       is usually retrieved with VCGetCurrEntityHandle after 
'       utilizing another database parsing routine.  Please 
'       see the the database parsing section for details on 
'       the methods available for accessing entity 
'       information.  For example, we will parse through an 
'       existing selection.

'   start at the first selected entity
Dim iKind
iKind = vcadd.FirstSelected()

Do While (vcadd.GetErrorCode() = 0)
    '   your tool would do whatever processing is required
    '       for example, make several duplicates

    '   match all the entity properties
    vcadd.MatchCurrentEntity()

    '   change only the desired properties:
    '       Note, when using VCDuplicate you may also change 
    '       any entity-specific setting, such 
    '       VCSetTextHeight, VCSetLeaderArrowType, etc.  
    '       If so, you should always check the entity type, 
    '       the iKind variable, to verify you have the 
    '       desired entity type.  For example, change color:

    vcadd.SetColorIndex(8)

    '   Get the current entity handle for reference:
    '       Since the duplicated entity is appended to the 
    '       end of the database, it is necessary to keep 
    '       track of the current entity handle so that you 
    '       can quickly move back to the original entity.  
    '       The following code stores the current entity 
    '       handle in a variable:

    hCurrEnt = vcadd.GetCurrentEntityHandle()

    '   Duplicate the entity:
    '       By duplicating the entity, the application is 
    '       recreating the entity with all the new settings.  
    '       The new entity is then appended to the end of the 
    '       database.  The following code duplicates the 
    '       current entity and applies the current settings 
    '       to the new entity:

    vcadd.Duplicate(hCurrEnt)

    '   Optional - Erase the old entity:
    '       Depending upon the purpose of your tool, it may 
    '       be necessary to erase the old entity from the 
    '       drawing after the new one has been added.   The 
    '       following code moves to the old entity and sets 
    '       it as erased in the database:

    vcadd.SetCurrentEntity(hCurrEnt)
    vcadd.SetCurrentErased()
    vcadd.DrawCurrentEntity()

    '   Draw the new entity:
    hEnt = vcadd.LastEntity()
    vcadd.SetCurrentEntity(hEnt)
    vcadd.DrawCurrentEntity()

    '   Optional - Instead of a duplicate, we can also apply 
    '   certain transformations to the original entity.  For 
    '   example, VCDuplicateWithTransform, 
    '   VCDuplicateWithRotate, VCDuplicateWithSkew, 
    '   VCDuplicateWithScale, and VCDuplicateWithMove and 
    '   duplicating in the same draw order 
    '   VCDuplicateInDrawOrder and 
    '   VCDuplicateWithTransformInDrawOrder.  For example, to 
    '   duplicate with a move (also called translation):

    pt0.X = 1.0 '   move 1 inch right
    pt0.Y = 1.0 '   move 1 inch up
    vcadd.DuplicateWithMove hCurrEnt, pt0, hCurrEnt

    '   Draw the new entity:
    hEnt = vcadd.LastEntity()
    vcadd.SetCurrentEntity(hEnt)
    vcadd.DrawCurrentEntity()

    '   The parsing routines move to the next entity after 
    '   the current entity.  Therefore, if code has changed 
    '   the current entity, as it has above to draw the last 
    '   entity, then you must set the current entity back to 
    '   the original before moving to the next entity.
    vcadd.SetCurrentEntity(hCurrEnt)

    '   move to the next entity
    iKind = vcadd.NextSelected()
Loop

'   Restore the user default settings:
'       The user settings should be returned to their 
'       position prior to the operation.  VCRestoreSettings 
'       resets the settings based on the temporary buffer. 

vcadd.RestoreSettings()

' release Visual CADD object
set vcadd = Nothing
