' VBScript to Retrieve User Data using tags
'   lines starting with an apostrophe are comments

' create Visual CADD object
set vcadd = CreateObject("VisualCADD.Application.9")

'   Set the required unique user data name in the application
'   initialization routine:
'       In order to access user data for each entity and the 
'       drawing header, a unique user data name must be 
'       specified to reference the information.  The user 
'       data name is case insensitive and can be up to 15 
'       characters long.  The following code sets a user 
'       data name of "MyData":

vcadd.SetUserDataName("MyData")

'   Retrieve the information to the current entity:
'       To access user data in the current entity, call 
'       VCSetEntityUserData.

vcadd.SetEntityUserData()

'     The current entity can be set in a number of ways 
'     using any of the Visual CADD API parsing routines or 
'     VCSetCurrentEntity.  For information see the topic 
'     Parsing the Database.  For illustration, we will use 
'     the first entity in the database with entity handle or 
'     index 0.  The user data will be retrieved from this 
'     current entity.

vcadd.SetCurrentEntity(0)

'   verify we have a current entity before proceeding
If (vcadd.GetErrorCode() = 0) Then
    '  Add Or set the desired user data values to the 
    '  current entity:
    '      As each user data item is added, a user data tag
    '      is attached to it to identify it for future access.

    vcadd.AddCurrentEntityUserDataShort(0)
    vcadd.SetCurrentEntityUserDataTag(0, 123)
    vcadd.AddCurrentEntityUserDataDouble(25.5)
    vcadd.SetCurrentEntityUserDataTag(1, 345)
    vcadd.AddCurrentEntityUserDataString("My Application Data")
    vcadd.SetCurrentEntityUserDataTag(2, 678)

    '  Retrieve the user data index for a tag
    '      This returns the index of the user data which
    '      has a tag value of 345. The search is started at index 0.
    '      For our example, the returned index will be 1.
    '      If more than one user data item had a tag value of 345,
    '      the subsequent indexes could be found by setting the start index
    '      to the current index value 

    Dim iIndex

    iIndex = vcadd.GetCurrentEntityUserDataTagIndex(345, 0)

    '  We can now access the user data. 
    '  If the application remembers the user data type
    '  for the item, you would just make direct calls to the 
    '  corresponding function for the index.

    Dim dDouble
    dDouble = vcadd.GetCurrentEntityUserDataDouble(iIndex)

    '  To illustrate the usefulness of tags, delete a user data item:
    '      Deleting user data item 0 (short) will cause the index
    '      of the following two items (the double And the string) to change.
    '      This time, finding a tag of 345 will return an index of 0.

    vcadd.DeleteCurrentEntityUserData(0)
    iIndex = vcadd.GetCurrentEntityUserDataTagIndex(345, 0)

    '  We can still access the double user data.

    dDouble = vcadd.GetCurrentEntityUserDataDouble(iIndex)
End If

' release Visual CADD object
set vcadd = Nothing
